
/*
 * This file is part of EKG/gEKG, a software package to record EKG.
 * Copyright  2003 Lars Stollenwerk
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or (at your
 * option) any later version.  
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#ifndef EKGTOOLS_H
#define EKGTOOLS_H

/**
 * @name Umrechnung von EKG-Ableitungen
 * Vom EKG-Gert werden die Ablietungen I, II und III nach Einthoven gemessen.
  <pre>
      R    O    L
          /|\    
      Rt / | \ Ge
           |         
          / \    
      Sw /   \ Gr
  </pre>
 * <dl>
 * <dt> I   <dd> Arm links  -> Arm rechts (gelb - rot)
 * <dt> II  <dd> Fu links  -> Arm rechts (grn - rot)
 * <dt> III <dd> Fu links  -> Arm links  (grn - gelb)
 * </dl>
 * Am rechten Fu (schwarz) ist die Erde angeschlossen.
 * <p>
 * Die folgenden Funktionen berechnen dararus die Ableitungen nach
 * Goldberger.
 * <dl>
 * <dt> aVR <dd> Arm rechts (rot) -> {gelb, grn}
 * <dt> aVL <dd> Arm links (gelb) -> {rot,  grn}
 * <dt> aVF <dd> Fu links (grn) -> {rot,  gelb}
 * </dl>
 * Die Elektroden in geschwungenen Klammern werden beide ber einen 100k
 * Widerstand an den negativen Eingang des Meverstrkers angeschlossen.
 * <p>
 * Wenn die Ableitungen I, II, III nach Eindhoven bekannt sind, knnen die
 * Ableitungen nach Goldberger berechnet werden. 
 */
//@{


/**
 * aVR berechnen.
 * aVR = rot - 0.5 ( gelb + grn )  <br>
 *     = rot/2 - gelb/2 + rot/2 - grn/2  <br>
 *     = - I/2 - II/2  <br>
 */
inline float aVR( const float * const d )
{
  return -0.5 * ( d[0] + d[1] );  
};


/**
 * aVL berechnen.
 * aVL = gelb - 0.5 ( rot + grn )  <br>
 *     = gelb/2 - rot/2 + gelb/2 - grn/2  <br>
 *     = I/2 - III/2  <br>
 */
inline float aVL( const float * const d )
{
  return 0.5 * ( d[0] - d[2] );
}


/**
 * aVF berechnen.
 * aVF = grn - 0.5 ( rot + gelb )  <br>
 *     = grn/2 - rot/2 + grn/2 - gelb/2  <br>
 *     = II/2 + III/2  <br>
 */
inline float aVF( const float * const d )
{
  return 0.5 * ( d[1] + d[2] );
}

//@}
#endif

